@@ -1,10 +1,9 @@
 #![allow(missing_docs)]
 
 use crate::{
-    driver::{connection::error::Error, Config},
-    events::EventData,
+    driver::{connection::error::Error, Bitrate, Config},
+    events::{context_data::DisconnectReason, EventData},
     tracks::Track,
-    Bitrate,
     ConnectionInfo,
 };
 use flume::Sender;
@@ -13,6 +12,8 @@ use flume::Sender;
 #[derive(Debug)]
 pub enum CoreMessage {
     ConnectWithResult(ConnectionInfo, Sender<Result<(), Error>>),
+    RetryConnect(usize),
+    SignalWsClosure(usize, ConnectionInfo, Option<DisconnectReason>),
     Disconnect,
     SetTrack(Option<Track>),
     AddTrack(Track),
